@@ -1,6 +1,6 @@
 ;;; (redis commands) --- redis module for Guile.
 
-;; Copyright (C) 2013-2021 Aleix Conchillo Flaque <aconchillo@gmail.com>
+;; Copyright (C) 2013-2022 Aleix Conchillo Flaque <aconchillo@gmail.com>
 ;;
 ;; This file is part of guile-redis.
 ;;
@@ -61,47 +61,60 @@
       (current-module)))))
 
 (create-commands
+ ;; Bitmap
+ (bitcount)
+ (bitfield)
+ (bitfield_ro)
+ (bitop)
+ (bitpos)
+ (getbit)
+ (setbit)
  ;; Cluster
+ (asking)
  (cluster addslots)
+ (cluster addslotsrange)
  (cluster bumpepoch)
  (cluster count-failure-reports)
  (cluster countkeysinslot)
  (cluster delslots)
+ (cluster delslotsrange)
  (cluster failover)
  (cluster flushslots)
  (cluster forget)
  (cluster getkeysinslot)
  (cluster info)
  (cluster keyslot)
+ (cluster links)
  (cluster meet)
  (cluster myid)
  (cluster nodes)
+ (cluster replicas)
  (cluster replicate)
  (cluster reset)
  (cluster saveconfig)
  (cluster set-config-epoch)
  (cluster setslot)
  (cluster slaves)
- (cluster replicas)
  (cluster slots)
  (readonly)
  (readwrite)
  ;; Connection
  (auth)
  (client caching)
+ (client getname)
+ (client getredir)
  (client id)
  (client info)
  (client kill)
  (client list)
- (client getname)
- (client getredir)
- (client unpause)
+ (client no-evict)
  (client pause)
  (client reply)
  (client setname)
  (client tracking)
  (client trackinginfo)
  (client unblock)
+ (client unpause)
  (echo)
  (hello)
  (ping)
@@ -110,11 +123,13 @@
  (select)
  ;; Geo
  (geoadd)
+ (geodist)
  (geohash)
  (geopos)
- (geodist)
  (georadius)
  (georadiusbymember)
+ (georadiusbymember_ro)
+ (georadius_ro)
  (geosearch)
  (geosearchstore)
  ;; Hashes
@@ -128,16 +143,18 @@
  (hlen)
  (hmget)
  (hmset)
+ (hrandfield)
+ (hscan)
  (hset)
  (hsetnx)
- (hrandfield)
  (hstrlen)
  (hvals)
- (hscan)
  ;; HyperLogLog
  (pfadd)
  (pfcount)
+ (pfdebug)
  (pfmerge)
+ (pfselftest)
  ;; Keys
  (copy)
  (del)
@@ -145,33 +162,42 @@
  (exists)
  (expire)
  (expireat)
+ (expiretime)
  (keys)
  (migrate)
  (move)
- (object)
+ (object encoding)
+ (object freq)
+ (object idletime)
+ (object refcount)
  (persist)
  (pexpire)
  (pexpireat)
+ (pexpiretime)
  (pttl)
  (randomkey)
  (rename)
  (renamenx)
  (restore)
+ (scan)
  (sort)
+ (sort_ro)
  (touch)
  (ttl)
  (type)
  (unlink)
  (wait)
- (scan)
  ;; Lists
+ (blmove)
+ (blmpop)
  (blpop)
  (brpop)
  (brpoplpush)
- (blmove)
  (lindex)
  (linsert)
  (llen)
+ (lmove)
+ (lmpop)
  (lpop)
  (lpos)
  (lpush)
@@ -182,54 +208,74 @@
  (ltrim)
  (rpop)
  (rpoplpush)
- (lmove)
  (rpush)
  (rpushx)
  ;; Pub/Sub
  ;; publish, subscribe, unsubscribe, etc. are defined in pubsub.scm.
- (pubsub)
+ (pubsub channels)
+ (pubsub numpat)
+ (pubsub numsub)
+ (pubsub shardchannels)
  ;; Scripting
  (eval)
  (evalsha)
+ (evalsha_ro)
+ (eval_ro)
+ (fcall)
+ (fcall_ro)
+ (function delete)
+ (function dump)
+ (function flush)
+ (function kill)
+ (function list)
+ (function load)
+ (function restore)
+ (function stats)
  (script debug)
  (script exists)
  (script flush)
  (script kill)
  (script load)
  ;; Server
- (acl load)
- (acl save)
- (acl list)
- (acl users)
- (acl getuser)
- (acl setuser)
- (acl deluser)
  (acl cat)
+ (acl deluser)
+ (acl dryrun)
  (acl genpass)
- (acl whoami)
+ (acl getuser)
+ (acl list)
+ (acl load)
  (acl log)
- (acl help)
+ (acl save)
+ (acl setuser)
+ (acl users)
+ (acl whoami)
  (bgrewriteaof)
  (bgsave)
  (command)
  (command count)
+ (command docs)
  (command getkeys)
+ (command getkeysandflags)
  (command info)
+ (command list)
  (config get)
+ (config resetstat)
  (config rewrite)
  (config set)
- (config resetstat)
  (dbsize)
- (debug object)
- (debug segfault)
  (failover)
  (flushall)
  (flushdb)
  (info)
- (lolwut)
  (lastsave)
+ (latency doctor)
+ (latency graph)
+ (latency histogram)
+ (latency history)
+ (latency latest)
+ (latency reset)
+ (lolwut)
  (memory doctor)
- (memory help)
  (memory malloc-stats)
  (memory purge)
  (memory stats)
@@ -238,42 +284,42 @@
  (module load)
  (module unload)
  (monitor)
+ (psync)
+ (replconf)
+ (replicaof)
+ (restore-asking)
  (role)
  (save)
  (shutdown)
  (slaveof)
- (replicaof)
- (slowlog)
+ (slowlog get)
+ (slowlog len)
+ (slowlog reset)
  (swapdb)
  (sync)
- (psync)
  (time)
- (latency doctor)
- (latency graph)
- (latency history)
- (latency latest)
- (latency reset)
- (latency help)
  ;; Sets
  (sadd)
  (scard)
  (sdiff)
  (sdiffstore)
  (sinter)
+ (sintercard)
  (sinterstore)
  (sismember)
- (smismember)
  (smembers)
+ (smismember)
  (smove)
  (spop)
  (srandmember)
  (srem)
+ (sscan)
  (sunion)
  (sunionstore)
- (sscan)
  ;; Sorted Sets
- (bzpopmin)
+ (bzmpop)
  (bzpopmax)
+ (bzpopmin)
  (zadd)
  (zcard)
  (zcount)
@@ -281,54 +327,58 @@
  (zdiffstore)
  (zincrby)
  (zinter)
+ (zintercard)
  (zinterstore)
  (zlexcount)
+ (zmpop)
+ (zmscore)
  (zpopmax)
  (zpopmin)
  (zrandmember)
- (zrangestore)
  (zrange)
  (zrangebylex)
- (zrevrangebylex)
  (zrangebyscore)
+ (zrangestore)
  (zrank)
  (zrem)
  (zremrangebylex)
  (zremrangebyrank)
  (zremrangebyscore)
  (zrevrange)
+ (zrevrangebylex)
  (zrevrangebyscore)
  (zrevrank)
+ (zscan)
  (zscore)
  (zunion)
- (zmscore)
  (zunionstore)
- (zscan)
  ;; Streams
- (xinfo)
- (xadd)
- (xtrim)
- (xdel)
- (xrange)
- (xrevrange)
- (xlen)
- (xread)
- (xgroup)
- (xreadgroup)
  (xack)
- (xclaim)
+ (xadd)
  (xautoclaim)
+ (xclaim)
+ (xdel)
+ (xgroup create)
+ (xgroup createconsumer)
+ (xgroup delconsumer)
+ (xgroup destroy)
+ (xgroup setid)
+ (xinfo consumers)
+ (xinfo groups)
+ (xinfo stream)
+ (xlen)
  (xpending)
+ (xrange)
+ (xread)
+ (xreadgroup)
+ (xrevrange)
+ (xsetid)
+ (xtrim)
  ;; Strings
  (append)
- (bitcount)
- (bitfield)
- (bitop)
- (bitpos)
  (decr)
  (decrby)
  (get)
- (getbit)
  (getdel)
  (getex)
  (getrange)
@@ -336,17 +386,17 @@
  (incr)
  (incrby)
  (incrbyfloat)
+ (lcs)
  (mget)
  (mset)
  (msetnx)
  (psetex)
  (set)
- (setbit)
  (setex)
  (setnx)
  (setrange)
- (stralgo)
  (strlen)
+ (substr)
  ;; Transactions
  (discard)
  (exec)
